========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/oslosphinx.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

=============================
 OpenStack Sphinx Extensions
=============================

.. image:: https://img.shields.io/pypi/v/oslosphinx.svg
    :target: https://pypi.python.org/pypi/oslosphinx/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslosphinx.svg
    :target: https://pypi.python.org/pypi/oslosphinx/
    :alt: Downloads

Theme and extension support for Sphinx documentation from the
OpenStack project.

Using the Theme
===============

Prior to using this theme, ensure your project can use the OpenStack
brand by referring to the brand guidelines at
http://www.openstack.org/brand.

* Free software: Apache License, Version 2.0
* Documentation: http://docs.openstack.org/developer/oslosphinx
* Source: http://git.openstack.org/cgit/openstack/oslosphinx
* Bugs: http://bugs.launchpad.net/oslosphinx
